#!/bin/bash -e

# Import shared functions
source /usr/local/bin/shared-baseimage.sh

function Usage {
    echo "USAGE: Formats /mnt to ext4 IF it is ntfs"
    echo "$0 [-y]"
    echo -e "\t-y Automatically proceed without confirmation prompt"
    exit 1
}

function PromptForConfirmation {
    echo "/mnt is formatted ntfs. Do you want to format ext4?"
    select yn in "Yes" "No"; do
        case $yn in
            Yes ) return;;
            No ) echo "Operation cancelled"; exit;;
        esac
    done
}

function RemountIfNeeded {
    if ! df -T | grep "/mnt"; then
        mount /mnt || bail "Failed to remount /mnt"
    fi
}

while getopts ":y" opt; do
  case $opt in
    y)
      skipConfirm=yes
      ;;
    \?)
      Usage
      ;;
    :)
      echo "Option -$OPTARG requires an argument." >&2
      Usage
      ;;
  esac
done

# Sometimes /mnt points to the drive, not the partition
fstab="/etc/fstab"
if IsFstabMntBroken $fstab; then
    echo "Attempting to fix entry for ephemeral drive in $fstab"
    set +e
    result=$(TryFixEphemeralDriveMapping $fstab)
    if [ $? -ne 0 ] ; then
        bail "$result"
    fi
    set -e
    echo "Will remount /mnt"
    ! umount /mnt
    # Remount /mnt later once the filesystem is validated
fi
    
ephemeralPartition=$(grep /mnt $fstab| awk '{print $1}')

if [ ! -b "$ephemeralPartition" ]; then
    RemountIfNeeded
    bail "Partition $ephemeralPartition does not exist"
fi

echo "Checking filesystem on $ephemeralPartition"
fs=$(blkid -c /dev/null $ephemeralPartition | awk '{print $3}')
if [ "$fs" == "TYPE=\"ntfs\"" ]; then
    if [ "$skipConfirm" != "yes" ]; then
       PromptForConfirmation
    fi
    echo "/mnt is NTFS - will format as ext4"
    ! umount /mnt
    echo y | mkfs.ext4 -q $ephemeralPartition
    fs=$(blkid -c /dev/null $ephemeralPartition | awk '{print $3}')
    # Remount outside the if clause
fi

RemountIfNeeded

if [ "$fs" != "TYPE=\"ext4\"" ]; then
    echo "ERROR: filesystem should be ext4, instead it's [$fs]"
    exit 1
else
    echo "OK: /mnt is ext4"
fi
